{
  open Parser open Lexing
  exception Eof
  let new_line lexbuf =
    let lcp = lexbuf.lex_curr_p in
    lexbuf.lex_curr_p <- { lcp with
      pos_lnum = lcp.pos_lnum + 1;
      pos_bol = lcp.pos_cnum;
    }
}
rule token = parse 
   |[' ' '\t' ]                                 { token lexbuf                  } 
   |['0'-'9']+ as lxm                           { INT(int_of_string lxm)        } 
   |"/\\"                                       { AND                           } 
   |"\\/"                                       { OR                            } 
   |"(+)"                                       { XOR                           } 
   |"<->"                                       { EQUIV                         } 
   |"->"                                        { IMPLY                         } 
   |".."                                        { DOTS                          } 
   |"<="                                        { LE                            } 
   |">="                                        { GE                            } 
   |":="                                        { DEF                           } 
   |"//"                                        { comment lexbuf                }
   |"let"                                       { LET                           }
   |"in"                                        { IN                            }
   |'\n'                                        { new_line lexbuf; token lexbuf }
   |'>'                                         { GT                            } 
   |'<'                                         { LT                            } 
   |'~'                                         { NOT                           } 
   |'|'                                         { ST                            } 
   |'+'                                         { PLUS                          } 
   |'='                                         { EQUAL                         } 
   |'_'                                         { INDEX                         } 
   |','                                         { COMMA                         } 
   |'-'                                         { MINUS                         } 
   |'('                                         { LPAREN                        } 
   |')'                                         { RPAREN                        } 
   |['a'-'z']['a'-'z''0'-'9'''']* as lxm        { VAR(lxm)                      } 
   |['A'-'Z']['A'-'Z''a'-'z''0'-'9'''']* as lxm { PROP(lxm)                     } 
   |eof                                         { EOF                           } 
and comment = parse
  |'\n' { new_line lexbuf; token lexbuf   }
  |_    { comment lexbuf }


