(** Strategies.
 *
 * We explicit the type for strategies because working with continuations is not particularly readable,
 * hence putting the focus on them and clearly defining their signatures help the understanding.
 *
 * @author Vincent Aravantinos
 *)

type 'a t = 
  |ModelFound of 'a (** since the beginning, at least one model has been found, notice that 'a will actually always be instantiated by Block.t *)
  |NoModelFound     (** no model has been found until now *)

val unsatisfiable : 'a t -> bool
val satisfiable   : 'a t -> bool
val model         : 'a t -> 'a option

(*(** Combines two satisfiability datas, intuitive:
  * a model has been found iff a model has been found for any of the two datas
  *)
val (&) : t -> t -> t*)
