open OUnit
open Parser
open Schema
open Indexes

let raises_exception f =
  try f (); false
  with _ -> true

let parsed s =
  let lexbuf = Lexing.from_string s in
  let (sch,_) = Parser.main Lexer.token lexbuf in
  sch

open Schema_test.Values

let test =
  "parser" >:::
    ["indexes" >::
      (fun () ->
        "number"       @? (parsed "P_1"   = p1);
        "variable"     @? (parsed "P_i"   = p_i);
        "parameter"    @? (parsed "P_n"   = p_n);
        "addition1"    @? (parsed "P_n+1" = p_nplus1);
        "addition2"    @? (parsed "P_n+0" = p_nplus0);
        "substraction" @? (parsed "P_n-1" = p_nminus1);
        "addsub"       @? raises_exception (fun () -> parsed "P_n+1-1");
        "intaddint"    @? raises_exception (fun () -> parsed "P_0+1");
        "intaddvar"    @? raises_exception (fun () -> parsed "P_0+n");
      );
    "propositional" >::
      (fun () ->
        "proposition1" @? (parsed "P_1" = p1);
        "proposition2" @? (parsed "Q_1" = q1);
        "negation"     @? (parsed "~Q_1" = nq1);
        "disjunction"  @? (parsed "P_1\\/Q_1" = p1_or_q1);
        "conjunction"  @? (parsed "P_1/\\Q_1" = p1_and_q1);
      );
      (*TODO more tests*)
    ]
